@@ -102,7 +102,7 @@ plugin_init ()
   if (err > 0)
   {
     fprintf (stderr,
-             _ ("Initialization of plugin mechanism failed: %s!\n"),
+             "Initialization of plugin mechanism failed: %s!\n",
              lt_dlerror ());
     return;
   }
